//Source file: DeliveryTimeType.java
//Date: November 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V7.1.0, Release 7

package org.csapi.jr.se.mmm;

/**
 * Defines whether a message shall be delivered instantly or at some specified time.
 *
 */
public final class DeliveryTimeType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static DeliveryTimeType[] _array = new DeliveryTimeType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DeliveryTimeType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The message shall be delivered as soon as possible.
     */
    public static final int _MMM_SEND_IMMEDIATE =  0;

    /**
     * The message shall be delivered as soon as possible.
     */
    public static final DeliveryTimeType MMM_SEND_IMMEDIATE = new DeliveryTimeType(_MMM_SEND_IMMEDIATE);

    /**
     * The message shall be delivered at a certain specified time.
     */
    public static final int _MMM_DELIVERY_TIME =  1;

    /**
     * The message shall be delivered at a certain specified time.
     */
    public static final DeliveryTimeType MMM_DELIVERY_TIME = new DeliveryTimeType(_MMM_DELIVERY_TIME);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DeliveryTimeType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DeliveryTimeType object
     */
    public String getValueText() {
        switch (_value) {
            case _MMM_SEND_IMMEDIATE:
                return "MMM_SEND_IMMEDIATE";
            case _MMM_DELIVERY_TIME:
                return "MMM_DELIVERY_TIME";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DeliveryTimeType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DeliveryTimeType)) {
            return false;
        }
        DeliveryTimeType deliveryTimeType = (DeliveryTimeType) o; 
        if(!(this.getValue() == deliveryTimeType.getValue())) {
            return false;
        }
        if (this.hashCode() != deliveryTimeType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DeliveryTimeType

