//Source file: MultiMediaMessagingManager.java
//Date: November 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V7.1.0, Release 7

package org.csapi.jr.se.mmm;

/**
 * This interface represents a MultiMediaMessagingManager.<BR>
 *
 */
public interface MultiMediaMessagingManager extends org.csapi.jr.se.Service {

    /**
     * Adds a MultiMediaMessagingManagerListener which is interested in events generated by the MultiMediaMessagingManager.
     *
     * @param  multiMediaMessagingManagerListener  A reference to the MultiMediaMessagingManagerListener which is to be added as
     *         a listener.
     */
    void addMultiMediaMessagingManagerListener(org.csapi.jr.se.mmm.MultiMediaMessagingManagerListener multiMediaMessagingManagerListener);

    /**
     * Removes a MultiMediaMessagingManagerListener which is no longer interested in events generated by the MultiMediaMessagingManager.
     *
     * @param  multiMediaMessagingManagerListener  A reference to the MultiMediaMessagingManagerListener which is to be removed as
     *         a listener.
     */
    void removeMultiMediaMessagingManagerListener(org.csapi.jr.se.mmm.MultiMediaMessagingManagerListener multiMediaMessagingManagerListener);

    /**
     * Invokes the getNextNotification() method on the Parlay Gateway.
     */
    org.csapi.jr.se.mmm.MessagingNotificationRequestedSetEntry getNextNotification(
           boolean                         reset)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the disableNotifications() method on the Parlay Gateway.
     */
    void disableNotifications()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the openMailbox() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.mmm.Mailbox openMailbox(
           java.lang.String                mailboxID,
           java.lang.String                authenticationInfo)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.mmm.MmmInvalidMailboxException,
       org.csapi.jr.se.mmm.MmmInvalidAuthenticationInformationException,
       org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Invokes the openMultiMediaMessaging() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.mmm.MultiMediaMessaging openMultiMediaMessaging(
           org.csapi.jr.se.mmm.TerminatingAddressList defaultDestinationAddressList,
           org.csapi.jr.se.Address defaultSourceAddress)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidInterfaceTypeException,
       org.csapi.jr.se.InvalidAddressException;

    /**
     * Creates a Notifications object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notifications interface.
     */
    org.csapi.jr.se.mmm.Notifications createNotifications();

    /**
     * Creates a Notification object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notification interface.
     */
    org.csapi.jr.se.mmm.Notification createNotification();

}
