//Source file: NewMessageArrivedInfo.java
//Date: November 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V7.1.0, Release 7

package org.csapi.jr.se.mmm;

/**
 * Defines the Sequence of Data Elements that specify the information returned to the application in a New Message Arrived event.  The Source and Destination addresses are included, as they are used in the criteria for this event.  The actual message received is included in the Message field.  This contains the entire message (headers and body) in unstructured format.  The Headers field contains header information which was sent as part of the message.  This information could be duplicated in the raw message, depending on its format.
 * 
 */
public final class NewMessageArrivedInfo implements java.io.Serializable {

    private org.csapi.jr.se.Address sourceAddress;
    private org.csapi.jr.se.Address[] destinationAddressSet;
    private byte[] message;
    private org.csapi.jr.se.mmm.MessageHeaderField[] headers;
    private org.csapi.jr.se.mmm.MultiMediaMessaging multiMediaMessaging;

    /**
     * Creates a new NewMessageArrivedInfo instance.
     */
    public NewMessageArrivedInfo () {}

    /**
     * Creates a new NewMessageArrivedInfo instance.
     * @param _sourceAddress   
     * @param _destinationAddressSet   
     * @param _message   
     * @param _headers   
     * @param _multiMediaMessaging   
     */
    public NewMessageArrivedInfo (org.csapi.jr.se.Address _sourceAddress, org.csapi.jr.se.Address[] _destinationAddressSet, byte[] _message, org.csapi.jr.se.mmm.MessageHeaderField[] _headers, org.csapi.jr.se.mmm.MultiMediaMessaging _multiMediaMessaging) {

        this.sourceAddress = _sourceAddress;
        this.destinationAddressSet = _destinationAddressSet;
        this.message = _message;
        this.headers = _headers;
        this.multiMediaMessaging = _multiMediaMessaging;
    }

    /**
     * This method returns a sourceAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getSourceAddress() {
        return sourceAddress;
    }

    /**
     * This method returns a destinationAddressSet.
     * 
     * @return a org.csapi.jr.se.Address[] value
     */
    public org.csapi.jr.se.Address[] getDestinationAddressSet() {
        return destinationAddressSet;
    }

    /**
     * This method returns a message.
     * 
     * @return a byte[] value
     */
    public byte[] getMessage() {
        return message;
    }

    /**
     * This method returns a headers.
     * 
     * @return a org.csapi.jr.se.mmm.MessageHeaderField[] value
     */
    public org.csapi.jr.se.mmm.MessageHeaderField[] getHeaders() {
        return headers;
    }

    /**
     * This method returns a multiMediaMessaging.
     * 
     * @return a org.csapi.jr.se.mmm.MultiMediaMessaging value
     */
    public org.csapi.jr.se.mmm.MultiMediaMessaging getMultiMediaMessaging() {
        return multiMediaMessaging;
    }


    /**
     * This method sets a sourceAddress.
     */ 
    public void setSourceAddress(org.csapi.jr.se.Address sourceAddress) {
        this.sourceAddress = sourceAddress;
    }

    /**
     * This method sets a destinationAddressSet.
     */ 
    public void setDestinationAddressSet(org.csapi.jr.se.Address[] destinationAddressSet) {
        this.destinationAddressSet = destinationAddressSet;
    }

    /**
     * This method sets a message.
     */ 
    public void setMessage(byte[] message) {
        this.message = message;
    }

    /**
     * This method sets a headers.
     */ 
    public void setHeaders(org.csapi.jr.se.mmm.MessageHeaderField[] headers) {
        this.headers = headers;
    }

    /**
     * This method sets a multiMediaMessaging.
     */ 
    public void setMultiMediaMessaging(org.csapi.jr.se.mmm.MultiMediaMessaging multiMediaMessaging) {
        this.multiMediaMessaging = multiMediaMessaging;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof NewMessageArrivedInfo)) {
            return false;
        } 
        NewMessageArrivedInfo newMessageArrivedInfo = (NewMessageArrivedInfo) o;
        if ((this.sourceAddress != null) && (newMessageArrivedInfo.sourceAddress != null)) {
            if(!(this.sourceAddress.equals(newMessageArrivedInfo.sourceAddress))) {
                return false;
            }
        }
        if(!(this.destinationAddressSet == newMessageArrivedInfo.destinationAddressSet))  {
            return false;
        }
        if(!(this.message == newMessageArrivedInfo.message))  {
            return false;
        }
        if(!(this.headers == newMessageArrivedInfo.headers))  {
            return false;
        }
        if ((this.multiMediaMessaging != null) && (newMessageArrivedInfo.multiMediaMessaging != null)) {
            if(!(this.multiMediaMessaging.equals(newMessageArrivedInfo.multiMediaMessaging))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // NewMessageArrivedInfo

