//Source file: SendMessage.java
//Date: November 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V7.1.0, Release 7

package org.csapi.jr.se.mmm;

/**
 * This interface represents a SendMessage activity object.<BR>
 *
 */
public interface SendMessage extends org.csapi.jr.se.Activity {

    /**
     * Returns a reference to the MultiMediaMessaging responsible for creation of the SendMessage.
     *
     * @return  A reference to the MultiMediaMessaging responsible for creation of the SendMessage.
     */
    org.csapi.jr.se.mmm.MultiMediaMessaging getMultiMediaMessaging();

    /**
     * Adds a SendMessageListener which is interested in events generated by the SendMessage.
     *
     * @param  sendMessageListener  A reference to the SendMessageListener which is to be added as
     *        a listener.
     */
    void addSendMessageListener(org.csapi.jr.se.mmm.SendMessageListener sendMessageListener);

    /**
     * Removes a SendMessageListener which is no longer interested events generated by the SendMessage.
     *
     * @param  sendMessageListener  A reference to the SendMessageListener which is to be removed as
     *        a listener.
     */
    void removeSendMessageListener(org.csapi.jr.se.mmm.SendMessageListener sendMessageListener);

    /**
     * Invokes the sendMessageReq() method on the Parlay Gateway.
     */
    void sendMessageReq(
           org.csapi.jr.se.Address sourceAddress,
           org.csapi.jr.se.mmm.TerminatingAddressList destinationAddressList,
           java.lang.String                deliveryType,
           org.csapi.jr.se.mmm.MessageTreatment[] messageTreatment,
           byte[]                          message,
           org.csapi.jr.se.mmm.MessageHeaderField[] additionalHeaders)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAddressException,
       org.csapi.jr.se.mmm.MmmInvalidDeliveryTypeException,
       org.csapi.jr.se.mmm.MmmMaxMessageSizeExceededException,
       org.csapi.jr.se.mmm.MmmDeliveryTypeAddressTypeMismatchException,
       org.csapi.jr.se.mmm.MmmDeliveryTypeMessageTypeMismatchException,
       org.csapi.jr.se.mmm.MmmInvalidDeliveryTimeException,
       org.csapi.jr.se.mmm.MmmInvalidValidityTimeException,
       org.csapi.jr.se.mmm.MmmMaxSubjectSizeExceededException,
       org.csapi.jr.se.mmm.MmmInvalidHeaderException;

    /**
     * Invokes the cancelMessageReq() method on the Parlay Gateway.
     */
    void cancelMessageReq()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.mmm.MmmCannotCancelException;


    /**
     * Invokes the queryStatusReq() method on the Parlay Gateway.
     */
    void queryStatusReq()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.mmm.MmmInformationNotAvailableException;

}
