//Source file: SetPropertyError.java
//Date: November 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V7.1.0, Release 7

package org.csapi.jr.se.mmm;

/**
 * Identifies the reason why a property was not set.
 *
 */
public final class SetPropertyError implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static SetPropertyError[] _array = new SetPropertyError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SetPropertyError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The property was not set.  No further information is available.
     */
    public static final int _MMM_PROPERTY_NOT_SET =  0;

    /**
     * The property was not set.  No further information is available.
     */
    public static final SetPropertyError MMM_PROPERTY_NOT_SET = new SetPropertyError(_MMM_PROPERTY_NOT_SET);

    /**
     * The property is readonly and cannot be modified by an application.
     */
    public static final int _MMM_PROPERTY_READONLY =  1;

    /**
     * The property is readonly and cannot be modified by an application.
     */
    public static final SetPropertyError MMM_PROPERTY_READONLY = new SetPropertyError(_MMM_PROPERTY_READONLY);

    /**
     * The application is not authorised to modify the property.
     */
    public static final int _MMM_PROPERTY_INSUFFICIENT_PRIVILEGE =  2;

    /**
     * The application is not authorised to modify the property.
     */
    public static final SetPropertyError MMM_PROPERTY_INSUFFICIENT_PRIVILEGE = new SetPropertyError(_MMM_PROPERTY_INSUFFICIENT_PRIVILEGE);

    /**
     * The property name is unknown.
     */
    public static final int _MMM_PROPERTY_NAME_UNKNOWN =  3;

    /**
     * The property name is unknown.
     */
    public static final SetPropertyError MMM_PROPERTY_NAME_UNKNOWN = new SetPropertyError(_MMM_PROPERTY_NAME_UNKNOWN);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SetPropertyError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SetPropertyError object
     */
    public String getValueText() {
        switch (_value) {
            case _MMM_PROPERTY_NOT_SET:
                return "MMM_PROPERTY_NOT_SET";
            case _MMM_PROPERTY_READONLY:
                return "MMM_PROPERTY_READONLY";
            case _MMM_PROPERTY_INSUFFICIENT_PRIVILEGE:
                return "MMM_PROPERTY_INSUFFICIENT_PRIVILEGE";
            case _MMM_PROPERTY_NAME_UNKNOWN:
                return "MMM_PROPERTY_NAME_UNKNOWN";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SetPropertyError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SetPropertyError)) {
            return false;
        }
        SetPropertyError setPropertyError = (SetPropertyError) o; 
        if(!(this.getValue() == setPropertyError.getValue())) {
            return false;
        }
        if (this.hashCode() != setPropertyError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SetPropertyError

